﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Infragistics.Win;
using Infragistics.Win.UltraWinGanttView.UIElements;
using System.Drawing;

namespace GanttSample
{
    public class CreationFilter : IUIElementCreationFilter
    {
        #region IUIElementCreationFilter method implementations
        public bool BeforeCreateChildElements(UIElement parent)
        {
            return false;
        }


        public void AfterCreateChildElements(UIElement parent)
        {
            if (parent == null)
                return;

            switch (parent.GetType().Name)
            {
                case "TaskUIElement":
                {
                    TaskUIElement uiElem = parent as TaskUIElement;
                    if (uiElem != null)
                    {
                        List<TaskBarUIElement> removeElemList = new List<TaskBarUIElement>();
                        List<TaskBarUIElementExt> addElemList = new List<TaskBarUIElementExt>();

                        TaskBarUIElement oldTaskElem;
                        foreach (UIElement currElem in uiElem.ChildElements)
                        {
                            oldTaskElem = currElem as TaskBarUIElement;
                            if (oldTaskElem != null)
                            {
                                removeElemList.Add(oldTaskElem);
                                addElemList.Add(TaskBarUIElementExt.FromTaskBarUIElement(oldTaskElem));
                            }
                        }

                        foreach (UIElement currElem in removeElemList)
                            uiElem.ChildElements.Remove(currElem);

                        uiElem.ChildElements.AddRange(addElemList);
                    }

                    break;
                }

                case "TaskBarTextUIElement":
                {
                    Infragistics.Win.UltraWinSchedule.Task task = parent.GetContext(
                        typeof(Infragistics.Win.UltraWinSchedule.Task))
                        as Infragistics.Win.UltraWinSchedule.Task;

                    if (task != null && task.Parent != null)
                    {
                        string respName = task.GetCustomProperty("ResponsibleUser").ToString();

                        var txtUIElem = ((Infragistics.Win.TextUIElement)(parent));
                        txtUIElem.Text = respName;
                        //txtUIElem.Rect = new Rectangle(parent.Rect.X + parent.Rect.Width + 20 + 4, parent.Rect.Y, 125, parent.Rect.Height);
                        txtUIElem.TextHAlign = HAlign.Left;
                        txtUIElem.TextVAlign = VAlign.Middle;

                        if (!string.IsNullOrEmpty(respName))
                        {
                            ;
                        }
                    }
                    break;
                }

                case "TaskBarUIElement":
                case "TaskBarUIElementExt":
                {
                    Infragistics.Win.UltraWinSchedule.Task task = parent.GetContext(
                        typeof(Infragistics.Win.UltraWinSchedule.Task))
                        as Infragistics.Win.UltraWinSchedule.Task;

                    if (task != null && task.Parent != null)
                    {
                        TaskAreaUIElement areaElem = parent.Parent.Parent as TaskAreaUIElement;

                        ImageUIElement imgElem = new ImageUIElement(parent, null);
                        imgElem.Rect = new Rectangle(parent.Rect.X + parent.Rect.Width + 2,
                            parent.Rect.Y, 20, parent.Rect.Height);
                        imgElem.CenterImage = true;
                        areaElem.ChildElements.Add(imgElem);

                        string respName = task.GetCustomProperty("ResponsibleUser").ToString();

                        /*
                        TextUIElement txtElem = new TextUIElement(parent, respName);
                        txtElem.Rect = new Rectangle(parent.Rect.X + parent.Rect.Width + imgElem.Rect.Width + 4,
                            parent.Rect.Y, 125, parent.Rect.Height);
                        txtElem.TextHAlign = HAlign.Left;
                        txtElem.TextVAlign = VAlign.Middle;
                        txtElem.BorderStyle = UIElementBorderStyle.Solid;
                        txtElem.BorderSides = System.Windows.Forms.Border3DSide.All;
                        areaElem.ChildElements.Add(txtElem);
                        */

                        //task.TimelineSettings.BarSettings.BarTextRight = BarTextField.ResourceNames;

                        if (!string.IsNullOrEmpty(respName))
                        {
                            ;
                        }

                    }

                    break;       
                }

                default:
                    break;
            }
        }        
        #endregion
    }
}
